nx.data.ObservableGraph.QuickProcessor - Next UI Toolkit

#

API Docs for: trial
Show: Inherited Protected Private Deprecated

# nx.data.ObservableGraph.QuickProcessor Class

Module: nx.data

Force layout processor

- Index
- Methods
- Properties

## Item Index

### Methods

- registerDataProcessor static

### Properties

- dataProcessor

## Methods

### `registerDataProcessor`

(

- `name`
- `cls`

)
static

Register graph data processor,

#### Parameters:

- `name` String

  data processor name

- `cls` Object

  processor instance, instance should have a process method

## Properties

### `dataProcessor`

Unknown

Set pre data processor,it could be 'force'/'quick'

Default: undefined